@@ -34,12 +34,11 @@
 #include <exchange-constants.h>
 #include "exchange-config-listener.h"
 #include <e-folder-exchange.h>
-#include <e-shell-marshal.h>
 
 #include "mail-stub-listener.h"
 #include "mail-stub-exchange.h"
 
-#include "exchange-migrate.h" 
+#include "exchange-migrate.h"
 
 #define d(x)
 
@@ -49,8 +48,8 @@ static void e_filename_make_safe (gchar *string);
 static void exchange_component_update_accounts (ExchangeComponent *component,
 							gboolean status);
 static void ex_migrate_esources (ExchangeComponent *component,
-				  const CORBA_short major, 
-				  const CORBA_short minor, 
+				  const CORBA_short major,
+				  const CORBA_short minor,
 				  const CORBA_short revision);
 
 static guint linestatus_signal_id;
@@ -128,7 +127,7 @@ dispose (GObject *object)
 		CORBA_exception_free (&ev);
 		CORBA_Object_release (priv->evo_listener, &ev);
 		CORBA_exception_free (&ev);
-		
+
 		priv->evo_listener = NULL;
 	}
 
@@ -146,12 +145,11 @@ impl_createView (PortableServer_Servant servant,
 		 GNOME_Evolution_ShellView parent,
 		 CORBA_Environment *ev)
 {
-	d(printf("createView...\n"));
-
 	EComponentView *component_view = e_component_view_new_controls (parent, "exchange",
                                                         		NULL,
 									NULL,
                                                         		NULL);
+	d(printf("createView...\n"));
 
         return BONOBO_OBJREF(component_view);
 }
@@ -183,10 +181,10 @@ impl_upgradeFromVersion (PortableServer_Servant servant,
 		e_filename_make_safe (base_directory);
 		account_filename = strrchr (base_directory, '/') + 1;
 
-		exchange_migrate(major, minor, revision, 
+		exchange_migrate(major, minor, revision,
 				 base_directory, account_filename);
-				 	
-		ex_migrate_esources (component, major, minor, revision);			
+
+		ex_migrate_esources (component, major, minor, revision);
 	}
 }
 
@@ -253,14 +251,14 @@ impl_setLineStatus (PortableServer_Servant servant,
 		case GNOME_Evolution_FORCED_OFFLINE:
 			priv->linestatus = FALSE;
 			break;
-		
+
 		case GNOME_Evolution_USER_ONLINE:
 			priv->linestatus = TRUE;
 			break;
 		default:
 			break;
 	}
-	
+
 	if (priv->cal_factory) {
 		e_data_cal_factory_set_backend_mode (priv->cal_factory,
 						     priv->linestatus ? ONLINE_MODE : OFFLINE_MODE);
@@ -288,8 +286,8 @@ impl_setLineStatus (PortableServer_Servant servant,
 
 static void
 ex_migrate_esources (ExchangeComponent *component,
-		  const CORBA_short major, 
-		  const CORBA_short minor, 
+		  const CORBA_short major,
+		  const CORBA_short minor,
 		  const CORBA_short revision)
 {
 
@@ -308,7 +306,7 @@ exchange_component_update_accounts (ExchangeComponent *component,
 	GSList *acc;
 
 	for (acc = priv->accounts; acc; acc = acc->next) {
-		baccount = acc->data;	
+		baccount = acc->data;
 		if (status)
 			exchange_account_set_online (baccount->account);
 		else
@@ -323,7 +321,7 @@ e_filename_make_safe (gchar *string)
 {
 	gchar *p, *ts;
 	gunichar c;
-	
+
 	g_return_if_fail (string != NULL);
 	p = string;
 
@@ -332,7 +330,7 @@ e_filename_make_safe (gchar *string)
 		ts = p;
 		p = g_utf8_next_char (p);
 		if (!g_unichar_isprint(c) || ( c < 0xff && strchr (" /'\"`&();|<>$%{}!", c&0xff ))) {
-			while (ts<p) 	
+			while (ts<p)
 				*ts++ = '_';
 		}
 	}
@@ -385,7 +383,7 @@ config_listener_account_created (ExchangeConfigListener *config_listener,
 
 	account_filename = strrchr (account->storage_dir, '/') + 1;
 	e_filename_make_safe (account_filename);
-	
+
 	path = g_strdup_printf ("/tmp/.exchange-%s/%s",
 				g_get_user_name (),
 				account_filename);
@@ -451,14 +449,14 @@ exchange_component_class_init (ExchangeComponentClass *klass)
 
 	klass->linestatus_notify = default_linestatus_notify_handler;
 
-	linestatus_signal_id = 
+	linestatus_signal_id =
 		g_signal_new ("linestatus-changed",
 			       G_TYPE_FROM_CLASS (klass),
 			       G_SIGNAL_RUN_LAST | G_SIGNAL_NO_RECURSE | G_SIGNAL_NO_HOOKS,
 			       G_STRUCT_OFFSET (ExchangeComponentClass, linestatus_notify),
 			       NULL,
 			       NULL,
-			       e_shell_marshal_VOID__INT,
+			       g_cclosure_marshal_VOID__INT,
 			       G_TYPE_NONE,
 			       1,
 			       G_TYPE_INT);
